@@ -368,15 +368,6 @@ def get_handlers_args_parser(add_help=False):
 
     parser.add_argument('--slug', metavar='SCHEDULE_SLUG',
                         help='Override schedule slug (e.g. rhel)')
-    parser.add_argument('--use-tji-file',
-                        help='Use TJI file when exporting into TJP',
-                        default=False,
-                        action='store_true')
-    parser.add_argument(
-        '--tjp-keep-tjx',
-        help='Keep tjx intermediate file when importing from TJP',
-        default=False,
-        action='store_true')
 
     parser.add_argument('--rally-iter', help='Rally iteration to import',
                         default='')
@@ -397,22 +388,6 @@ def get_handlers_args_parser(add_help=False):
                         metavar='SRC_STORAGE_FORMAT',
                         help='Source storage format to use')
 
-    parser.add_argument('--cvs-repo-name',
-                        help='Name of CVS repository to checkout')
-    parser.add_argument('--cvs-root',
-                        help='Root of CVS repository')
-    parser.add_argument('--cvs-checkout-path',
-                        help='Path to shared working copy of CVS repository')
-    parser.add_argument(
-        '--cvs-exclusive-access',
-        help='Restrict to run just one CVS command at the same time',
-        action='store_true')
-    parser.add_argument(
-        '--cvs-lock-redis-uri',
-        help='Redis URI that is required by --cvs-exclusive-access, '
-             'default: localhost:6379/0',
-        default='localhost:6379/0')
-
     parser.add_argument('--smartsheet-token',
                         help='Access token for using SmartSheet API')
 
