@@ -1,12 +1,11 @@
-from schedules_tools.schedule_handlers import ScheduleHandlerBase
-from schedules_tools import models
-import datetime
 import logging
-import os
-from lxml import etree
+
+from schedules_tools.schedule_handlers import ScheduleHandlerBase
+
 
 log = logging.getLogger(__name__)
 
+
 class ScheduleHandler_abc(ScheduleHandlerBase):
     provide_export = True
 
